@@ -141,9 +141,8 @@ class EtagMixin:
             raw_data = etag_schema.dump(etag_data)
         if extra_data:
             raw_data = (raw_data, extra_data)
-        # flask's json.dumps is needed here
-        # as vanilla json.dumps chokes on lazy_strings
-        data = json.dumps(raw_data, sort_keys=True)
+        # Use flask.json to respect app settings, specifically JSON_SORT_KEYS
+        data = json.dumps(raw_data)
         return hashlib.sha1(bytes(data, "utf-8")).hexdigest()
 
     def _check_precondition(self):
