@@ -482,6 +482,66 @@ class TestBlueprint:
         assert "parameters" not in paths["/test/"]
         assert paths["/test/{user_id}"]["parameters"][0]["name"] == "user_id"
 
+    @pytest.mark.parametrize("as_method_view", (True, False))
+    def test_blueprint_url_prefix_path_parameter(self, app, as_method_view):
+        """Test registering a blueprint with path parameter in url_prefix
+
+        Checks path parameters in url_prefix are correctly documented, even
+        if registering the same Blueprint multiple times with a different url_prefix.
+        """
+        api = Api(app)
+        blp = Blueprint("test", __name__, url_prefix="/<int:user_id>")
+
+        if as_method_view:
+
+            @blp.route("/")
+            class Resource(MethodView):
+                def get(self, user_id):
+                    pass
+
+        else:
+
+            @blp.route("/")
+            def func(user_id):
+                pass
+
+        api.register_blueprint(blp)
+        api.register_blueprint(blp, url_prefix="/<int:team_id>", name="team")
+
+        paths = api.spec.to_dict()["paths"]
+
+        assert paths["/{user_id}/"]["parameters"][0]["name"] == "user_id"
+        assert paths["/{team_id}/"]["parameters"][0]["name"] == "team_id"
+
+    @pytest.mark.parametrize("openapi_version", ("2.0", "3.0.2"))
+    def test_blueprint_url_prefix_register_blueprint_parameters(
+        self, app, openapi_version
+    ):
+        """Check url_prefix path parameters docs are merged with auto docs"""
+        app.config["OPENAPI_VERSION"] = openapi_version
+        api = Api(app)
+        blp = Blueprint("test", __name__, url_prefix="/<int:item_id>/")
+
+        parameters = [
+            "TestParameter",
+            {"name": "item_id", "in": "path", "description": "Item ID"},
+        ]
+
+        @blp.route("/")
+        def get(item_id):
+            pass
+
+        api.register_blueprint(blp, parameters=parameters)
+        spec = api.spec.to_dict()
+        params = spec["paths"]["/{item_id}/"]["parameters"]
+        assert len(params) == 2
+        assert params[0] == build_ref(api.spec, "parameter", "TestParameter")
+        assert params[1]["description"] == "Item ID"
+        if openapi_version == "2.0":
+            assert params[1]["type"] == "integer"
+        else:
+            assert params[1]["schema"]["type"] == "integer"
+
     @pytest.mark.parametrize("openapi_version", ("2.0", "3.0.2"))
     def test_blueprint_route_multiple_methods(self, app, schemas, openapi_version):
         """Test calling route with multiple methods
@@ -710,6 +770,39 @@ class TestBlueprint:
         get = api.spec.to_dict()["paths"]["/test/"]["get"]
         assert get["responses"]["200"]["headers"] == headers
 
+    @pytest.mark.parametrize("openapi_version", ("2.0", "3.0.2"))
+    @pytest.mark.parametrize("content_type", ("application/x-custom", None))
+    def test_blueprint_reponse_content_type(
+        self, app, schemas, openapi_version, content_type
+    ):
+        app.config["OPENAPI_VERSION"] = openapi_version
+        api = Api(app)
+        blp = Blueprint("test", "test", url_prefix="/test")
+
+        @blp.route("/")
+        @blp.response(200, schemas.DocSchema, content_type=content_type)
+        def func():
+            pass
+
+        api.register_blueprint(blp)
+
+        get = api.spec.to_dict()["paths"]["/test/"]["get"]
+
+        if openapi_version == "2.0":
+            if content_type is not None:
+                assert set(get["produces"]) == {
+                    "application/json",
+                    "application/x-custom",
+                }
+            else:
+                assert "produces" not in get
+        else:
+            assert "produces" not in get
+            assert get["responses"]["200"]["content"] == {
+                content_type
+                or "application/json": {"schema": build_ref(api.spec, "schema", "Doc")}
+            }
+
     @pytest.mark.parametrize("default_error", ("default", "override", "None"))
     def test_blueprint_documents_default_error_response(self, app, default_error):
         class MyApi(Api):
@@ -741,10 +834,8 @@ class TestBlueprint:
 
     @pytest.mark.parametrize("openapi_version", ["2.0", "3.0.2"])
     @pytest.mark.parametrize("schema_type", ["object", "ref"])
-    def test_blueprint_alt_response_schema(
-        self, app, openapi_version, schemas, schema_type
-    ):
-        """Check alternate response schema is correctly documented"""
+    def test_blueprint_alt_response(self, app, openapi_version, schemas, schema_type):
+        """Check alternate response is correctly documented"""
         app.config["OPENAPI_VERSION"] = openapi_version
         api = Api(app)
         blp = Blueprint("test", "test", url_prefix="/test")
@@ -793,6 +884,11 @@ class TestBlueprint:
         def func_with_headers():
             pass
 
+        @blp.route("/content_type")
+        @blp.alt_response(400, schema=schema, content_type="application/x-custom")
+        def func_with_content_type():
+            pass
+
         api.register_blueprint(blp)
 
         paths = api.spec.to_dict()["paths"]
@@ -822,6 +918,16 @@ class TestBlueprint:
         response = paths["/test/headers"]["get"]["responses"]["400"]
         assert response["headers"] == headers
 
+        get = paths["/test/content_type"]["get"]
+        if openapi_version == "2.0":
+            assert set(get["produces"]) == {"application/json", "application/x-custom"}
+        else:
+            assert "produces" not in get
+        if openapi_version == "3.0.2":
+            assert get["responses"]["400"]["content"] == {
+                "application/x-custom": {"schema": schema_ref}
+            }
+
     @pytest.mark.parametrize("openapi_version", ["2.0", "3.0.2"])
     def test_blueprint_alt_response_ref(self, app, openapi_version):
         """Check alternate response passed as reference"""
