@@ -24,11 +24,10 @@ def implicit_data_and_schema_etag_blueprint(collection, schemas):
 
     DocSchema = schemas.DocSchema
 
-    blp = Blueprint('test', __name__, url_prefix='/test')
+    blp = Blueprint("test", __name__, url_prefix="/test")
 
-    @blp.route('/')
+    @blp.route("/")
     class Resource(MethodView):
-
         @blp.etag
         @blp.response(200, DocSchema(many=True))
         @blp.paginate(Page)
@@ -41,9 +40,8 @@ def implicit_data_and_schema_etag_blueprint(collection, schemas):
         def post(self, new_item):
             return collection.post(new_item)
 
-    @blp.route('/<int:item_id>')
+    @blp.route("/<int:item_id>")
     class ResourceById(MethodView):
-
         def _get_item(self, item_id):
             try:
                 return collection.get_by_id(item_id)
@@ -84,19 +82,17 @@ def implicit_data_explicit_schema_etag_blueprint(collection, schemas):
     DocSchema = schemas.DocSchema
     DocEtagSchema = schemas.DocEtagSchema
 
-    blp = Blueprint('test', __name__, url_prefix='/test')
+    blp = Blueprint("test", __name__, url_prefix="/test")
 
-    @blp.route('/')
+    @blp.route("/")
     class Resource(MethodView):
-
         @blp.etag(DocEtagSchema(many=True))
         @blp.response(200, DocSchema(many=True))
         @blp.paginate()
         def get(self, pagination_parameters):
             pagination_parameters.item_count = len(collection.items)
             return collection.items[
-                pagination_parameters.first_item:
-                pagination_parameters.last_item + 1
+                pagination_parameters.first_item : pagination_parameters.last_item + 1
             ]
 
         @blp.etag(DocEtagSchema)
@@ -105,9 +101,8 @@ def implicit_data_explicit_schema_etag_blueprint(collection, schemas):
         def post(self, new_item):
             return collection.post(new_item)
 
-    @blp.route('/<int:item_id>')
+    @blp.route("/<int:item_id>")
     class ResourceById(MethodView):
-
         def _get_item(self, item_id):
             try:
                 return collection.get_by_id(item_id)
@@ -151,11 +146,10 @@ def explicit_data_no_schema_etag_blueprint(collection, schemas):
 
     DocSchema = schemas.DocSchema
 
-    blp = Blueprint('test', __name__, url_prefix='/test')
+    blp = Blueprint("test", __name__, url_prefix="/test")
 
-    @blp.route('/')
+    @blp.route("/")
     class Resource(MethodView):
-
         @blp.etag
         @blp.response(200, DocSchema(many=True))
         @blp.paginate()
@@ -164,8 +158,7 @@ def explicit_data_no_schema_etag_blueprint(collection, schemas):
             # It is better to rely on automatic ETag here, as it includes
             # pagination metadata.
             return collection.items[
-                pagination_parameters.first_item:
-                pagination_parameters.last_item + 1
+                pagination_parameters.first_item : pagination_parameters.last_item + 1
             ]
 
         @blp.etag
@@ -173,12 +166,11 @@ def explicit_data_no_schema_etag_blueprint(collection, schemas):
         @blp.response(201, DocSchema)
         def post(self, new_item):
             # Compute ETag using arbitrary data and no schema
-            blp.set_etag(new_item['db_field'])
+            blp.set_etag(new_item["db_field"])
             return collection.post(new_item)
 
-    @blp.route('/<int:item_id>')
+    @blp.route("/<int:item_id>")
     class ResourceById(MethodView):
-
         def _get_item(self, item_id):
             try:
                 return collection.get_by_id(item_id)
@@ -190,7 +182,7 @@ def explicit_data_no_schema_etag_blueprint(collection, schemas):
         def get(self, item_id):
             item = self._get_item(item_id)
             # Compute ETag using arbitrary data and no schema
-            blp.set_etag(item['db_field'])
+            blp.set_etag(item["db_field"])
             return item
 
         @blp.etag
@@ -199,10 +191,10 @@ def explicit_data_no_schema_etag_blueprint(collection, schemas):
         def put(self, new_item, item_id):
             item = self._get_item(item_id)
             # Check ETag is a manual action, no shema used
-            blp.check_etag(item['db_field'])
+            blp.check_etag(item["db_field"])
             new_item = collection.put(item_id, new_item)
             # Compute ETag using arbitrary data and no schema
-            blp.set_etag(new_item['db_field'])
+            blp.set_etag(new_item["db_field"])
             return new_item
 
         @blp.etag
@@ -210,24 +202,25 @@ def explicit_data_no_schema_etag_blueprint(collection, schemas):
         def delete(self, item_id):
             item = self._get_item(item_id)
             # Check ETag is a manual action, no shema used
-            blp.check_etag(item['db_field'])
+            blp.check_etag(item["db_field"])
             collection.delete(item_id)
 
     return blp
 
 
-@pytest.fixture(params=[
-    (implicit_data_and_schema_etag_blueprint, 'Schema'),
-    (implicit_data_explicit_schema_etag_blueprint, 'ETag schema'),
-    (explicit_data_no_schema_etag_blueprint, 'No schema'),
-])
+@pytest.fixture(
+    params=[
+        (implicit_data_and_schema_etag_blueprint, "Schema"),
+        (implicit_data_explicit_schema_etag_blueprint, "ETag schema"),
+        (explicit_data_no_schema_etag_blueprint, "No schema"),
+    ]
+)
 def blueprint_fixture(request, collection, schemas):
     blp_factory = request.param[0]
     return blp_factory(collection, schemas), request.param[1]
 
 
 class TestFullExample:
-
     def test_examples(self, app, blueprint_fixture, schemas):
 
         blueprint, bp_schema = blueprint_fixture
@@ -239,7 +232,8 @@ class TestFullExample:
 
         @contextmanager
         def assert_counters(
-                schema_load, schema_dump, etag_schema_load, etag_schema_dump):
+            schema_load, schema_dump, etag_schema_load, etag_schema_dump
+        ):
             """Check number of calls to dump/load methods of schemas"""
             schemas.DocSchema.reset_load_count()
             schemas.DocSchema.reset_dump_count()
@@ -252,173 +246,193 @@ class TestFullExample:
             assert schemas.DocEtagSchema.dump_count == etag_schema_dump
 
         # GET collection without ETag: OK
-        with assert_counters(0, 1, 0, 1 if bp_schema == 'ETag schema' else 0):
-            response = client.get('/test/')
+        with assert_counters(0, 1, 0, 1 if bp_schema == "ETag schema" else 0):
+            response = client.get("/test/")
             assert response.status_code == 200
-            list_etag = response.headers['ETag']
+            list_etag = response.headers["ETag"]
             assert len(response.json) == 0
-            assert json.loads(response.headers['X-Pagination']) == {
-                'total': 0, 'total_pages': 0}
+            assert json.loads(response.headers["X-Pagination"]) == {
+                "total": 0,
+                "total_pages": 0,
+            }
 
         # GET collection with correct ETag: Not modified
-        with assert_counters(0, 1, 0, 1 if bp_schema == 'ETag schema' else 0):
-            response = client.get(
-                '/test/',
-                headers={'If-None-Match': list_etag}
-            )
+        with assert_counters(0, 1, 0, 1 if bp_schema == "ETag schema" else 0):
+            response = client.get("/test/", headers={"If-None-Match": list_etag})
         assert response.status_code == 304
 
         # POST item_1
-        item_1_data = {'field': 0}
-        with assert_counters(1, 1, 0, 1 if bp_schema == 'ETag schema' else 0):
+        item_1_data = {"field": 0}
+        with assert_counters(1, 1, 0, 1 if bp_schema == "ETag schema" else 0):
             response = client.post(
-                '/test/',
-                data=json.dumps(item_1_data),
-                content_type='application/json'
+                "/test/", data=json.dumps(item_1_data), content_type="application/json"
             )
         assert response.status_code == 201
-        item_1_id = response.json['item_id']
+        item_1_id = response.json["item_id"]
 
         # GET collection with wrong/outdated ETag: OK
-        with assert_counters(0, 1, 0, 1 if bp_schema == 'ETag schema' else 0):
-            response = client.get(
-                '/test/',
-                headers={'If-None-Match': list_etag}
-            )
+        with assert_counters(0, 1, 0, 1 if bp_schema == "ETag schema" else 0):
+            response = client.get("/test/", headers={"If-None-Match": list_etag})
         assert response.status_code == 200
-        list_etag = response.headers['ETag']
+        list_etag = response.headers["ETag"]
         assert len(response.json) == 1
-        assert response.json[0] == {'field': 0, 'item_id': 1}
-        assert json.loads(response.headers['X-Pagination']) == {
-            'total': 1, 'total_pages': 1, 'page': 1,
-            'first_page': 1, 'last_page': 1}
+        assert response.json[0] == {"field": 0, "item_id": 1}
+        assert json.loads(response.headers["X-Pagination"]) == {
+            "total": 1,
+            "total_pages": 1,
+            "page": 1,
+            "first_page": 1,
+            "last_page": 1,
+        }
 
         # GET by ID without ETag: OK
-        with assert_counters(0, 1, 0, 1 if bp_schema == 'ETag schema' else 0):
-            response = client.get('/test/{}'.format(item_1_id))
+        with assert_counters(0, 1, 0, 1 if bp_schema == "ETag schema" else 0):
+            response = client.get(f"/test/{item_1_id}")
         assert response.status_code == 200
-        item_etag = response.headers['ETag']
+        item_etag = response.headers["ETag"]
 
         # GET by ID with correct ETag: Not modified
-        with assert_counters(0, 0 if bp_schema == 'No schema' else 1,
-                             0, 1 if bp_schema == 'ETag schema' else 0):
+        with assert_counters(
+            0,
+            0 if bp_schema == "No schema" else 1,
+            0,
+            1 if bp_schema == "ETag schema" else 0,
+        ):
             response = client.get(
-                '/test/{}'.format(item_1_id),
-                headers={'If-None-Match': item_etag}
+                f"/test/{item_1_id}", headers={"If-None-Match": item_etag}
             )
         assert response.status_code == 304
 
         # PUT without ETag: Precondition required error
-        item_1_data['field'] = 1
+        item_1_data["field"] = 1
         with assert_counters(0, 0, 0, 0):
             response = client.put(
-                '/test/{}'.format(item_1_id),
+                f"/test/{item_1_id}",
                 data=json.dumps(item_1_data),
-                content_type='application/json'
+                content_type="application/json",
             )
         assert response.status_code == 428
 
         # PUT with correct ETag: OK
-        with assert_counters(1, 2 if bp_schema == 'Schema' else 1,
-                             0, 2 if bp_schema == 'ETag schema' else 0):
+        with assert_counters(
+            1,
+            2 if bp_schema == "Schema" else 1,
+            0,
+            2 if bp_schema == "ETag schema" else 0,
+        ):
             response = client.put(
-                '/test/{}'.format(item_1_id),
+                f"/test/{item_1_id}",
                 data=json.dumps(item_1_data),
-                content_type='application/json',
-                headers={'If-Match': item_etag}
+                content_type="application/json",
+                headers={"If-Match": item_etag},
             )
         assert response.status_code == 200
-        new_item_etag = response.headers['ETag']
+        new_item_etag = response.headers["ETag"]
 
         # PUT with wrong/outdated ETag: Precondition failed error
-        item_1_data['field'] = 2
-        with assert_counters(1, 1 if bp_schema == 'Schema' else 0,
-                             0, 1 if bp_schema == 'ETag schema' else 0):
+        item_1_data["field"] = 2
+        with assert_counters(
+            1,
+            1 if bp_schema == "Schema" else 0,
+            0,
+            1 if bp_schema == "ETag schema" else 0,
+        ):
             response = client.put(
-                '/test/{}'.format(item_1_id),
+                f"/test/{item_1_id}",
                 data=json.dumps(item_1_data),
-                content_type='application/json',
-                headers={'If-Match': item_etag}
+                content_type="application/json",
+                headers={"If-Match": item_etag},
             )
         assert response.status_code == 412
 
         # GET by ID with wrong/outdated ETag: OK
-        with assert_counters(0, 1, 0, 1 if bp_schema == 'ETag schema' else 0):
+        with assert_counters(0, 1, 0, 1 if bp_schema == "ETag schema" else 0):
             response = client.get(
-                '/test/{}'.format(item_1_id),
-                headers={'If-None-Match': item_etag}
+                f"/test/{item_1_id}", headers={"If-None-Match": item_etag}
             )
         assert response.status_code == 200
 
         # GET collection with pagination set to 1 element per page
-        with assert_counters(0, 1, 0, 1 if bp_schema == 'ETag schema' else 0):
+        with assert_counters(0, 1, 0, 1 if bp_schema == "ETag schema" else 0):
             response = client.get(
-                '/test/',
-                headers={'If-None-Match': list_etag},
-                query_string={'page': 1, 'page_size': 1}
+                "/test/",
+                headers={"If-None-Match": list_etag},
+                query_string={"page": 1, "page_size": 1},
             )
         assert response.status_code == 200
-        list_etag = response.headers['ETag']
+        list_etag = response.headers["ETag"]
         assert len(response.json) == 1
-        assert response.json[0] == {'field': 1, 'item_id': 1}
-        assert json.loads(response.headers['X-Pagination']) == {
-            'total': 1, 'total_pages': 1, 'page': 1,
-            'first_page': 1, 'last_page': 1}
+        assert response.json[0] == {"field": 1, "item_id": 1}
+        assert json.loads(response.headers["X-Pagination"]) == {
+            "total": 1,
+            "total_pages": 1,
+            "page": 1,
+            "first_page": 1,
+            "last_page": 1,
+        }
 
         # POST item_2
-        item_2_data = {'field': 1}
-        with assert_counters(1, 1, 0, 1 if bp_schema == 'ETag schema' else 0):
+        item_2_data = {"field": 1}
+        with assert_counters(1, 1, 0, 1 if bp_schema == "ETag schema" else 0):
             response = client.post(
-                '/test/',
-                data=json.dumps(item_2_data),
-                content_type='application/json'
+                "/test/", data=json.dumps(item_2_data), content_type="application/json"
             )
         assert response.status_code == 201
 
         # GET collection with pagination set to 1 element per page
         # Content is the same (item_1) but pagination metadata has changed
         # so we don't get a 304 and the data is returned again
-        with assert_counters(0, 1, 0, 1 if bp_schema == 'ETag schema' else 0):
+        with assert_counters(0, 1, 0, 1 if bp_schema == "ETag schema" else 0):
             response = client.get(
-                '/test/',
-                headers={'If-None-Match': list_etag},
-                query_string={'page': 1, 'page_size': 1}
+                "/test/",
+                headers={"If-None-Match": list_etag},
+                query_string={"page": 1, "page_size": 1},
             )
         assert response.status_code == 200
-        list_etag = response.headers['ETag']
+        list_etag = response.headers["ETag"]
         assert len(response.json) == 1
-        assert response.json[0] == {'field': 1, 'item_id': 1}
-        assert json.loads(response.headers['X-Pagination']) == {
-            'total': 2, 'total_pages': 2, 'page': 1,
-            'first_page': 1, 'last_page': 2, 'next_page': 2}
+        assert response.json[0] == {"field": 1, "item_id": 1}
+        assert json.loads(response.headers["X-Pagination"]) == {
+            "total": 2,
+            "total_pages": 2,
+            "page": 1,
+            "first_page": 1,
+            "last_page": 2,
+            "next_page": 2,
+        }
 
         # DELETE without ETag: Precondition required error
         with assert_counters(0, 0, 0, 0):
-            response = client.delete('/test/{}'.format(item_1_id))
+            response = client.delete(f"/test/{item_1_id}")
         assert response.status_code == 428
 
         # DELETE with wrong/outdated ETag: Precondition failed error
-        with assert_counters(0, 1 if bp_schema == 'Schema' else 0,
-                             0, 1 if bp_schema == 'ETag schema' else 0):
+        with assert_counters(
+            0,
+            1 if bp_schema == "Schema" else 0,
+            0,
+            1 if bp_schema == "ETag schema" else 0,
+        ):
             response = client.delete(
-                '/test/{}'.format(item_1_id),
-                headers={'If-Match': item_etag}
+                f"/test/{item_1_id}", headers={"If-Match": item_etag}
             )
         assert response.status_code == 412
 
         # DELETE with correct ETag: No Content
-        with assert_counters(0, 1 if bp_schema == 'Schema' else 0,
-                             0, 1 if bp_schema == 'ETag schema' else 0):
+        with assert_counters(
+            0,
+            1 if bp_schema == "Schema" else 0,
+            0,
+            1 if bp_schema == "ETag schema" else 0,
+        ):
             response = client.delete(
-                '/test/{}'.format(item_1_id),
-                headers={'If-Match': new_item_etag}
+                f"/test/{item_1_id}", headers={"If-Match": new_item_etag}
             )
         assert response.status_code == 204
 
 
 class TestCustomExamples:
-
-    @pytest.mark.parametrize('openapi_version', ('2.0', '3.0.2'))
+    @pytest.mark.parametrize("openapi_version", ("2.0", "3.0.2"))
     def test_response_payload_wrapping(self, app, schemas, openapi_version):
         """Demonstrates how to wrap response payload in a data field"""
 
@@ -428,7 +442,7 @@ class TestCustomExamples:
             @staticmethod
             def _prepare_response_content(data):
                 if data is not None:
-                    return {'data': data}
+                    return {"data": data}
                 return None
 
             # Document data wrapper
@@ -437,46 +451,45 @@ class TestCustomExamples:
             def _make_doc_response_schema(schema):
                 if schema:
                     return type(
-                        'Wrap' + schema.__class__.__name__,
-                        (ma.Schema, ),
-                        {'data': ma.fields.Nested(schema)},
+                        "Wrap" + schema.__class__.__name__,
+                        (ma.Schema,),
+                        {"data": ma.fields.Nested(schema)},
                     )
                 return None
 
-        app.config['OPENAPI_VERSION'] = openapi_version
+        app.config["OPENAPI_VERSION"] = openapi_version
         api = Api(app)
         client = app.test_client()
-        blp = WrapperBlueprint('test', __name__, url_prefix='/test')
+        blp = WrapperBlueprint("test", __name__, url_prefix="/test")
 
-        @blp.route('/')
+        @blp.route("/")
         @blp.response(200, schemas.DocSchema)
         def func():
-            return {'item_id': 1, 'db_field': 42}
+            return {"item_id": 1, "db_field": 42}
 
         api.register_blueprint(blp)
         spec = api.spec.to_dict()
 
         # Test data is wrapped
-        resp = client.get('/test/')
-        assert resp.json == {'data': {'item_id': 1, 'field': 42}}
+        resp = client.get("/test/")
+        assert resp.json == {"data": {"item_id": 1, "field": 42}}
 
         # Test wrapping is correctly documented
-        if openapi_version == '3.0.2':
-            content = spec['paths']['/test/']['get']['responses']['200'][
-                'content']['application/json']
+        if openapi_version == "3.0.2":
+            content = spec["paths"]["/test/"]["get"]["responses"]["200"]["content"][
+                "application/json"
+            ]
         else:
-            content = spec['paths']['/test/']['get']['responses']['200']
-        assert content['schema'] == build_ref(api.spec, 'schema', 'WrapDoc')
-        assert get_schemas(api.spec)['WrapDoc'] == {
-            'type': 'object',
-            'properties': {'data': build_ref(api.spec, 'schema', 'Doc')}
+            content = spec["paths"]["/test/"]["get"]["responses"]["200"]
+        assert content["schema"] == build_ref(api.spec, "schema", "WrapDoc")
+        assert get_schemas(api.spec)["WrapDoc"] == {
+            "type": "object",
+            "properties": {"data": build_ref(api.spec, "schema", "Doc")},
         }
-        assert 'Doc' in get_schemas(api.spec)
+        assert "Doc" in get_schemas(api.spec)
 
-    @pytest.mark.parametrize('openapi_version', ('2.0', '3.0.2'))
-    def test_pagination_in_response_payload(
-            self, app, schemas, openapi_version
-    ):
+    @pytest.mark.parametrize("openapi_version", ("2.0", "3.0.2"))
+    def test_pagination_in_response_payload(self, app, schemas, openapi_version):
         """Demonstrates how to add pagination metadata in response payload"""
 
         class WrapperBlueprint(Blueprint):
@@ -484,95 +497,101 @@ class TestCustomExamples:
             # Set pagination metadata in app context
             def _set_pagination_metadata(self, page_params, result, headers):
                 page_meta = self._make_pagination_metadata(
-                    page_params.page, page_params.page_size,
-                    page_params.item_count)
-                get_appcontext()['pagination_metadata'] = page_meta
+                    page_params.page, page_params.page_size, page_params.item_count
+                )
+                get_appcontext()["pagination_metadata"] = page_meta
                 return result, headers
 
             # Wrap payload data and add pagination metadata if any
             @staticmethod
             def _prepare_response_content(data):
                 if data is not None:
-                    ret = {'data': data}
-                    page_meta = get_appcontext().get('pagination_metadata')
+                    ret = {"data": data}
+                    page_meta = get_appcontext().get("pagination_metadata")
                     if page_meta is not None:
-                        ret['pagination'] = page_meta
+                        ret["pagination"] = page_meta
                     return ret
                 return None
 
             # Document data wrapper and pagination in payload
             @staticmethod
             def _prepare_response_doc(doc, doc_info, spec, **kwargs):
-                operation = doc_info.get('response', {})
+                operation = doc_info.get("response", {})
                 if operation:
-                    success_code = doc_info['success_status_code']
-                    response = operation.get('responses', {}).get(success_code)
-                    if response is not None:
-                        if 'schema' in response:
-                            schema = response['schema']
-                            response['schema'] = type(
-                                'Wrap' + schema.__class__.__name__,
-                                (ma.Schema, ),
-                                {'data': ma.fields.Nested(schema)},
-                            )
-                            if 'pagination' in doc_info:
-                                schema = response['schema']
-                                response['schema'] = type(
-                                    'Pagination' + schema.__name__,
-                                    (schema, ),
-                                    {
-                                        'pagination': ma.fields.Nested(
-                                            PaginationMetadataSchema)
-                                    },
+                    success_status_codes = doc_info.get("success_status_codes", [])
+                    for success_status_code in success_status_codes:
+                        response = operation.get("responses", {}).get(
+                            success_status_code
+                        )
+                        if response is not None:
+                            if "schema" in response:
+                                schema = response["schema"]
+                                response["schema"] = type(
+                                    "Wrap" + schema.__class__.__name__,
+                                    (ma.Schema,),
+                                    {"data": ma.fields.Nested(schema)},
                                 )
-                return super(
-                    WrapperBlueprint, WrapperBlueprint
-                )._prepare_response_doc(doc, doc_info, spec=spec, **kwargs)
+                                if "pagination" in doc_info:
+                                    schema = response["schema"]
+                                    response["schema"] = type(
+                                        "Pagination" + schema.__name__,
+                                        (schema,),
+                                        {
+                                            "pagination": ma.fields.Nested(
+                                                PaginationMetadataSchema
+                                            )
+                                        },
+                                    )
+                return super(WrapperBlueprint, WrapperBlueprint)._prepare_response_doc(
+                    doc, doc_info, spec=spec, **kwargs
+                )
 
-        app.config['OPENAPI_VERSION'] = openapi_version
+        app.config["OPENAPI_VERSION"] = openapi_version
         api = Api(app)
         client = app.test_client()
-        blp = WrapperBlueprint('test', __name__, url_prefix='/test')
+        blp = WrapperBlueprint("test", __name__, url_prefix="/test")
 
-        @blp.route('/')
+        @blp.route("/")
         @blp.response(200, schemas.DocSchema(many=True))
         @blp.paginate(Page)
         def func():
             return [
-                {'item_id': 1, 'db_field': 42},
-                {'item_id': 2, 'db_field': 69},
+                {"item_id": 1, "db_field": 42},
+                {"item_id": 2, "db_field": 69},
             ]
 
         api.register_blueprint(blp)
         spec = api.spec.to_dict()
 
         # Test data is wrapped and pagination metadata added
-        resp = client.get('/test/')
+        resp = client.get("/test/")
         assert resp.json == {
-            'data': [{'field': 42, 'item_id': 1}, {'field': 69, 'item_id': 2}],
-            'pagination': {
-                'page': 1, 'first_page': 1, 'last_page': 1,
-                'total': 2, 'total_pages': 1,
-            }
+            "data": [{"field": 42, "item_id": 1}, {"field": 69, "item_id": 2}],
+            "pagination": {
+                "page": 1,
+                "first_page": 1,
+                "last_page": 1,
+                "total": 2,
+                "total_pages": 1,
+            },
         }
 
         # Test pagination is correctly documented
-        if openapi_version == '3.0.2':
-            content = spec['paths']['/test/']['get']['responses']['200'][
-                'content']['application/json']
+        if openapi_version == "3.0.2":
+            content = spec["paths"]["/test/"]["get"]["responses"]["200"]["content"][
+                "application/json"
+            ]
         else:
-            content = spec['paths']['/test/']['get']['responses']['200']
-        assert content['schema'] == build_ref(
-            api.spec, 'schema', 'PaginationWrapDoc')
-        assert get_schemas(api.spec)['PaginationWrapDoc'] == {
-            'type': 'object',
-            'properties': {
-                'data': {
-                    'items': build_ref(api.spec, 'schema', 'Doc'),
-                    'type': 'array',
+            content = spec["paths"]["/test/"]["get"]["responses"]["200"]
+        assert content["schema"] == build_ref(api.spec, "schema", "PaginationWrapDoc")
+        assert get_schemas(api.spec)["PaginationWrapDoc"] == {
+            "type": "object",
+            "properties": {
+                "data": {
+                    "items": build_ref(api.spec, "schema", "Doc"),
+                    "type": "array",
                 },
-                'pagination': build_ref(
-                    api.spec, 'schema', 'PaginationMetadata'),
-            }
+                "pagination": build_ref(api.spec, "schema", "PaginationMetadata"),
+            },
         }
-        assert 'Doc' in get_schemas(api.spec)
+        assert "Doc" in get_schemas(api.spec)
